@@ -102,7 +102,7 @@ class Course:
             os.makedirs(self.path(item), exist_ok=True)
 
     def download_videos(self, s: SessionWithKey) -> List[PreMediaContainer]:
-        if config.download_videos:
+        if not config.download_videos:
             return []
 
         url = "https://isis.tu-berlin.de/lib/ajax/service.php"
